==> ph-xservlet-9.1.1-sources.jar: com/helger/xservlet/filter/XServletFilterTimer.java <==
/**
 * Copyright (C) 2016-2019 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.xservlet.filter;

import javax.annotation.Nonnull;

import com.helger.commons.statistics.IMutableStatisticsHandlerKeyedTimer;
import com.helger.commons.statistics.StatisticsManager;
import com.helger.commons.timing.StopWatch;
import com.helger.web.scope.IRequestWebScope;
import com.helger.xservlet.AbstractXServlet;

/**
 * A special filter that performs timing of servlet execution. Each servlet
 * request requires it's own instance of this class!
 *
 * @author Philip Helger
 * @since 9.0.0
 */
public final class XServletFilterTimer implements IXServletHighLevelFilter
{
  private final IMutableStatisticsHandlerKeyedTimer m_aTimer;
  private StopWatch m_aSW;

  public XServletFilterTimer (@Nonnull final AbstractXServlet aServlet)
  {
    m_aTimer = StatisticsManager.getKeyedTimerHandler (aServlet.getClass ().getName ());
  }

  public void beforeRequest (@Nonnull final IRequestWebScope aRequestScope)
  {
    m_aSW = StopWatch.createdStarted ();
  }

  public void afterRequest (@Nonnull final IRequestWebScope aRequestScope)
  {
    // Timer per HTTP method
    m_aTimer.addTime (aRequestScope.getHttpMethod ().getName (), m_aSW.stopAndGetMillis ());
  }
}

==> ph-xservlet-9.3.4-sources.jar: com/helger/xservlet/filter/XServletFilterTimer.java <==
/**
 * Copyright (C) 2016-2020 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.xservlet.filter;

import javax.annotation.Nonnull;

import com.helger.commons.http.EHttpMethod;
import com.helger.commons.statistics.IMutableStatisticsHandlerKeyedTimer;
import com.helger.commons.statistics.StatisticsManager;
import com.helger.commons.timing.StopWatch;
import com.helger.web.scope.IRequestWebScope;
import com.helger.xservlet.AbstractXServlet;

/**
 * A special filter that performs timing of servlet execution. Each servlet
 * request requires it's own instance of this class!
 *
 * @author Philip Helger
 * @since 9.0.0
 */
public final class XServletFilterTimer implements IXServletHighLevelFilter
{
  private final IMutableStatisticsHandlerKeyedTimer m_aTimer;
  private StopWatch m_aSW;

  public XServletFilterTimer (@Nonnull final AbstractXServlet aServlet)
  {
    m_aTimer = StatisticsManager.getKeyedTimerHandler (aServlet.getClass ().getName ());
  }

  public void beforeRequest (@Nonnull final IRequestWebScope aRequestScope)
  {
    m_aSW = StopWatch.createdStarted ();
  }

  public void afterRequest (@Nonnull final IRequestWebScope aRequestScope)
  {
    // Timer per HTTP method
    final EHttpMethod eMethod = aRequestScope.getHttpMethod ();
    if (eMethod != null)
      m_aTimer.addTime (eMethod.getName (), m_aSW.stopAndGetMillis ());
  }
}
